@@ -40,12 +40,12 @@ ItemMimeData::~ItemMimeData()
 {
 }
 
-void ItemMimeData::appendTransfer(const QWeakPointer<TransferHandler> &transfer)
+void ItemMimeData::appendTransfer(const QPointer<TransferHandler> &transfer)
 {
     m_transfers.append(transfer);
 }
 
-QList<QWeakPointer<TransferHandler> > ItemMimeData::transfers() const
+QList<QPointer<TransferHandler> > ItemMimeData::transfers() const
 {
     return m_transfers;
 }
@@ -108,7 +108,7 @@ QVariant TransferModelItem::data(int role) const
                 //store the icon for speed improvements, KIconLoader should make sure, that
                 //the icon data gets shared
                 if (m_mimeType.isNull()) {
-                    m_mimeType = QIcon::fromTheme(KIO::iconNameForUrl(m_transferHandler->dest().url()));
+                    m_mimeType = QIcon::fromTheme(KIO::iconNameForUrl(m_transferHandler->dest()));
                 }
 
                 return m_mimeType;
@@ -583,7 +583,7 @@ QMimeData * TransferTreeModel::mimeData(const QModelIndexList &indexes) const
         if (index.isValid() && index.column() == 0 && index.parent().isValid()) {
             ModelItem *item = itemFromIndex(index);
             if (!item->isGroup()) {
-                mimeData->appendTransfer(QWeakPointer<TransferHandler>(item->asTransfer()->transferHandler()));
+                mimeData->appendTransfer(QPointer<TransferHandler>(item->asTransfer()->transferHandler()));
             }
         }
     }
@@ -611,9 +611,9 @@ bool TransferTreeModel::dropMimeData(const QMimeData * mdata, Qt::DropAction act
 
     if (parent.isValid())
         qCDebug(KGET_DEBUG) << "TransferTreeModel::dropMimeData" << " " << row << " " 
-                                                          << column << endl;
+                                                          << column;
 
-    QList<QWeakPointer<TransferHandler> > transfers = itemData->transfers();
+    QList<QPointer<TransferHandler> > transfers = itemData->transfers();
     qCDebug(KGET_DEBUG) << "TransferTreeModel::dropMimeData:" << transfers.count() << "transfers.";
 
     const bool droppedInsideGroup = parent.isValid();
