@@ -27,7 +27,7 @@
 #include <QDomElement>
 
 #include "kget_debug.h"
-#include <qdebug.h>
+#include <QDebug>
 
 #ifdef HAVE_QCA2
 #include <qca_basic.h>
@@ -379,7 +379,7 @@ void Verifier::verify(const QModelIndex &index)
         checksum = d->model->index(row, VerificationModel::Checksum).data().toString();
     }
 
-    d->thread.verifiy(type, checksum, d->dest);
+    d->thread.verify(type, checksum, d->dest);
 }
 
 void Verifier::brokenPieces() const
