@@ -48,15 +48,15 @@ namespace kt
 		void changeTC(bt::TorrentInterface* tc);
 		void update();
 
-		virtual int rowCount(const QModelIndex &parent) const;
-		virtual int columnCount(const QModelIndex &parent) const;
-		virtual QVariant data(const QModelIndex &index, int role) const;
-		virtual bool setData(const QModelIndex & index,const QVariant & value,int role);
-		virtual QVariant headerData(int section, Qt::Orientation orientation,int role) const;
-		virtual bool insertRows(int row,int count,const QModelIndex & parent);
-		virtual bool removeRows(int row,int count,const QModelIndex & parent);
-		virtual Qt::ItemFlags flags(const QModelIndex & index) const;
-		virtual QModelIndex index(int row,int column,const QModelIndex & parent = QModelIndex()) const;
+		virtual int rowCount(const QModelIndex &parent) const override;
+		virtual int columnCount(const QModelIndex &parent) const override;
+		virtual QVariant data(const QModelIndex &index, int role) const override;
+		virtual bool setData(const QModelIndex & index,const QVariant & value,int role) override;
+		virtual QVariant headerData(int section, Qt::Orientation orientation,int role) const override;
+		virtual bool insertRows(int row,int count,const QModelIndex & parent) override;
+		virtual bool removeRows(int row,int count,const QModelIndex & parent) override;
+		virtual Qt::ItemFlags flags(const QModelIndex & index) const override;
+		virtual QModelIndex index(int row,int column,const QModelIndex & parent = QModelIndex()) const override;
 		
 		/// Get a tracker url given a model index
 		QUrl trackerUrl(const QModelIndex & idx);
