@@ -59,7 +59,7 @@ void ChecksumSearchController::registerSearch(ChecksumSearchTransferDataSource *
             qCDebug(KGET_DEBUG) << "Creating download for" << baseUrl;
             static int files = 0;
 
-            const QUrl dest = QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QStringLiteral("/checksumsearch/") + QString::number(files++));
+            const QUrl dest = QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QStringLiteral("/checksumsearch/") + QString::number(files++));
             if (QFile::exists(dest.toLocalFile())) {
                 KIO::Job *del = KIO::del(dest, KIO::HideProgressInfo);
                 if (!del->exec()) {
@@ -71,13 +71,13 @@ void ChecksumSearchController::registerSearch(ChecksumSearchTransferDataSource *
                 qCDebug(KGET_DEBUG) << "Downloading" << baseUrl;
                 KIO::FileCopyJob *job = KIO::file_copy(baseUrl, dest, -1, KIO::HideProgressInfo);
                 job->addMetaData("errorPage", "false");
-                connect(job, SIGNAL(result(KJob*)), SLOT(slotResult(KJob*)));
+                connect(job, &KJob::result, this, &ChecksumSearchController::slotResult);
                 m_jobs[job] = qMakePair(baseUrl, dest);
             } else {
                 qCDebug(KGET_DEBUG) << "ftp, doing a listjob";
                 KIO::ListJob *job = KIO::listDir(baseUrl, KIO::HideProgressInfo);
-                connect(job, SIGNAL(entries(KIO::Job*,KIO::UDSEntryList)), this, SLOT(slotEntries(KIO::Job*,KIO::UDSEntryList)));
-                connect(job, SIGNAL(result(KJob*)), SLOT(slotResult(KJob*)));
+                connect(job, &KIO::ListJob::entries, this, &ChecksumSearchController::slotEntries);
+                connect(job, &KJob::result, this, &ChecksumSearchController::slotResult);
                 m_jobs[job] = qMakePair(baseUrl, dest);
             }
         }
