@@ -38,8 +38,8 @@ TransferDetails::TransferDetails(TransferHandler * transfer)
     //This updates the widget with the right values
     slotTransferChanged(transfer, 0xFFFFFFFF);
 
-    connect(transfer, SIGNAL(transferChangedEvent(TransferHandler*,TransferHandler::ChangesFlags)),
-            this,     SLOT(slotTransferChanged(TransferHandler*,TransferHandler::ChangesFlags)));
+    connect(transfer, &TransferHandler::transferChangedEvent,
+            this,     &TransferDetails::slotTransferChanged);
 }
 
 TransferDetails::~TransferDetails()
